#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class MouseXYtoBarTimePriceExample : Indicator
	{
		private ChartScale						chartScale;
		private Point							clickPoint	= new Point();
		private double							convertedPrice;
		private DateTime						convertedTime;
		
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description							= @"Demonstrates how to capture a mouse click and adjust for DPI settings properly";
				Name								= "MouseXYtoBarTimePriceExample";
				Calculate							= Calculate.OnBarClose;
				IsOverlay							= true;
				DisplayInDataBox					= false;
				DrawOnPricePanel					= true;
				ScaleJustification					= NinjaTrader.Gui.Chart.ScaleJustification.Right;
			}
			else if (State == State.Historical)
			{
				if (ChartControl != null)
				{
					foreach (ChartScale scale in ChartPanel.Scales)
						if (scale.ScaleJustification == ScaleJustification)
							chartScale = scale;

					ChartControl.MouseLeftButtonDown += MouseClicked;
				}
			}
			else if (State == State.Terminated)
			{
				if (ChartControl != null)
					ChartControl.MouseLeftButtonDown -= MouseClicked;
			}
		}

		protected override void OnBarUpdate() {	}
				
		protected void MouseClicked(object sender, MouseButtonEventArgs e)
		{
			// convert e.GetPosition for different dpi settings
			clickPoint.X = ChartingExtensions.ConvertToHorizontalPixels(e.GetPosition(ChartControl as IInputElement).X, ChartControl.PresentationSource);
			clickPoint.Y = ChartingExtensions.ConvertToVerticalPixels(e.GetPosition(ChartControl as IInputElement).Y, ChartControl.PresentationSource);

			convertedPrice	= Instrument.MasterInstrument.RoundToTickSize(chartScale.GetValueByY((float)clickPoint.Y));

			convertedTime	= ChartControl.GetTimeBySlotIndex((int)ChartControl.GetSlotIndexByX((int)clickPoint.X));

			Draw.TextFixed(this, "priceTime", string.Format("Price: {0}, Time: {1}", convertedPrice, convertedTime), TextPosition.BottomLeft);

			ForceRefresh();
		}
	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private MouseXYtoBarTimePriceExample[] cacheMouseXYtoBarTimePriceExample;
		public MouseXYtoBarTimePriceExample MouseXYtoBarTimePriceExample()
		{
			return MouseXYtoBarTimePriceExample(Input);
		}

		public MouseXYtoBarTimePriceExample MouseXYtoBarTimePriceExample(ISeries<double> input)
		{
			if (cacheMouseXYtoBarTimePriceExample != null)
				for (int idx = 0; idx < cacheMouseXYtoBarTimePriceExample.Length; idx++)
					if (cacheMouseXYtoBarTimePriceExample[idx] != null &&  cacheMouseXYtoBarTimePriceExample[idx].EqualsInput(input))
						return cacheMouseXYtoBarTimePriceExample[idx];
			return CacheIndicator<MouseXYtoBarTimePriceExample>(new MouseXYtoBarTimePriceExample(), input, ref cacheMouseXYtoBarTimePriceExample);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.MouseXYtoBarTimePriceExample MouseXYtoBarTimePriceExample()
		{
			return indicator.MouseXYtoBarTimePriceExample(Input);
		}

		public Indicators.MouseXYtoBarTimePriceExample MouseXYtoBarTimePriceExample(ISeries<double> input )
		{
			return indicator.MouseXYtoBarTimePriceExample(input);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.MouseXYtoBarTimePriceExample MouseXYtoBarTimePriceExample()
		{
			return indicator.MouseXYtoBarTimePriceExample(Input);
		}

		public Indicators.MouseXYtoBarTimePriceExample MouseXYtoBarTimePriceExample(ISeries<double> input )
		{
			return indicator.MouseXYtoBarTimePriceExample(input);
		}
	}
}

#endregion
